function [fwdIG,bwdIG,fwdAngle,bwdAngle,fwdMag,bwdMag] = circhistogramplot(anns,beats,x,whichfig);

if nargin<4
  whichfig = 1;
end

% plots error onto the unit circle

params = be_params;
params.informationGain.numBins = 40;

if any(anns > 1000)
  anns = anns/44100;
end

if any(beats > 1000)
  beats = beats/44100;
end


sunity = @(x) (x/sum(x));

% run code to get all the data...
[I,binVals,fwdEntropy,bwdEntropy,fwdBinVals,bwdBinVals,histBins] = be_informationGain(anns,beats,params);

%% Information Gain
fwdIG = log2(params.informationGain.numBins)-fwdEntropy;
bwdIG = log2(params.informationGain.numBins)-bwdEntropy;

%% CHANGE: Probability of error and offset estimate extracted from the maximum peak
% We could integrate over different regions of the histogram estimate of
% the pdf to obtain a probability of error, allowing or not metrical levels
% or off-beat cases.  
% A mask could be defined to weight more or less the different regions to
% penalize some of the regions.

pdf_fwd = fwdBinVals/sum(fwdBinVals); % fwd pdf estimate
pdf_bwd = bwdBinVals/sum(bwdBinVals); % bwd pdf estimate


%% Mean Angle
% want also to get mean angle and mean angle strength
% code examples taken from CircStat toolbox..
clear r; 
r = fwdBinVals*exp(1i*(2*pi*histBins'));
fwdAngle = angle(r);
fwdMag = abs(r)/sum(fwdBinVals);

clear r;
r = bwdBinVals*exp(1i*(2*pi*histBins'));
bwdAngle = angle(r);
bwdMag = abs(r)/sum(bwdBinVals);

plot_range = [52 60]; %  this is based on getting the right time range for the file...
%x = x([plot_range(1)*44100:plot_range(2)*44100]);


figure;
subplot(243); cla;
bar(histBins,sunity(fwdBinVals),'FaceColor','k'); xlim([-0.5,0.5]); title({'(b)'; 'Fwd Beat'; 'Error Histogram'});
xlabel('\it{z_k}');
ylabel('\it{p(z_k)}','Rotation',0);


subplot(247); cla;
bar(histBins,sunity(bwdBinVals),'FaceColor','k');xlim([-0.5,0.5]); title({'(e)'; 'Bwd Beat'; 'Error Histogram'});
xlabel('\it{z_k}');
ylabel('\it{p(z_k)}','Rotation',0);



subplot(244); cla;
% % % bins = fftshift(sunity(fwdBinVals));
bins = sunity(fwdBinVals);
stem3(cos(histBins * 2*pi), sin(histBins * 2*pi),bins,'k','MarkerSize',0);
hold on; plot3(cos(histBins * 2*pi), sin(histBins * 2*pi),(0.*bins),'k--');
hold on; plot3(cos([histBins histBins(1)]* 2*pi), sin([histBins histBins(1)]* 2*pi),[bins bins(1)],'k');
%xlabel('cos(x)'),ylabel('sin(x)'); 
box off;
title({'(c)' ; 'Fwd Circular'; 'Histogram'});
%title({'(c) ' ['Entropy: ',num2str(fwdEntropy)] ; [ 'Inf. Gain: ',num2str(fwdIG)]});
%zlabel('\it{p(z_k)}','Rotation',0,'FontName','Times New Roman','FontSize',13);
axis square;
view([98.5 40.8]); 

subplot(248); cla;
% % % bins = fftshift(sunity(bwdBinVals));
bins = sunity(bwdBinVals);
stem3(cos(histBins * 2*pi), sin(histBins * 2*pi),bins,'k','MarkerSize',0); 
hold on; plot3(cos(histBins * 2*pi), sin(histBins * 2*pi),(0.*bins),'k--');
hold on; plot3(cos([histBins histBins(1)]* 2*pi), sin([histBins histBins(1)]* 2*pi),[bins bins(1)],'k');
%xlabel('cos(x)'),ylabel('sin(x)'); 
box off;
title({'(f)' ; 'Bwd Circular';'Histogram'});
%zlabel('\it{p(z_k)}','Rotation',0,'FontName','Times New Roman','FontSize',13);
axis square;
view([98.5 40.8]); 

subplot(221); cla;
plot([plot_range(1)*44100:plot_range(2)*44100]/44100,x,'Color',[0.7 0.7 0.7]);
hold on;
stem(anns,ones(1,length(anns)),'k','Marker','None');
hold on;
stem(beats,-1*ones(1,length(beats)),'k--','Marker','None');
xlim([0 2+max([beats(:)' anns(:)'])]);
title({'(a)' ;'Annotations (solid) and Beats (dashed)'});
%title('{\color{blue}annotations \color{red}beats}');
xlim([plot_range]);
ylabel('Amplitude');

% temporary switch
b2 = beats;
beats = anns;
anns = b2;

subplot(223); cla;
plot([plot_range(1)*44100:plot_range(2)*44100]/44100,x,'Color',[0.7 0.7 0.7]);
hold on;
stem(beats,-1*ones(1,length(beats)),'k--','Marker','None');
%stem(anns,ones(1,length(anns)),'k','Marker','None');
hold on;
stem(anns,ones(1,length(anns)),'k','Marker','None');
%stem(beats,-1*ones(1,length(beats)),'k--','Marker','None');
xlim([0 2+max([beats(:)' anns(:)'])]);
title({'(d)' ;'Beats (solid) and Annotations (dashed)'});
%title('{\color{blue}annotations \color{red}beats}');
xlabel('time (s)');
xlim([plot_range]);
ylabel('Amplitude');

